@@ -17,8 +17,7 @@ config_bp = Blueprint(
     url_prefix=f"{constants.COMMANDS.SLASH_DELIM}{api_constants.MGMT_WEBAPP.CONFIG_RESOURCE}")
 
 
-@config_bp.route("", methods=[api_constants.MGMT_WEBAPP.HTTP_REST_GET,
-                              api_constants.MGMT_WEBAPP.HTTP_REST_PUT])
+@config_bp.route("", methods=[api_constants.MGMT_WEBAPP.HTTP_REST_GET, api_constants.MGMT_WEBAPP.HTTP_REST_PUT])
 def config():
     """
     The /config resource.
@@ -69,20 +68,3 @@ def registration_allowed():
     response_dict[api_constants.MGMT_WEBAPP.REGISTRATION_ALLOWED_PROPERTY] = allow_registration
     response = jsonify(response_dict)
     return response, constants.HTTPS.OK_STATUS_CODE
-
-
-@config_bp.route(f"{constants.COMMANDS.SLASH_DELIM}{api_constants.MGMT_WEBAPP.HOST_TERMINAL_ALLOWED_SUBRESOURCE}",
-                 methods=[api_constants.MGMT_WEBAPP.HTTP_REST_GET])
-def host_terminal_allowed():
-    """
-    The /config/host-terminal-allowed resource.
-
-    :return: The CSLE configuration
-    """
-    allow_host_terminal = False
-    if constants.CONFIG_FILE.PARSED_CONFIG is not None and constants.CONFIG_FILE.PARSED_CONFIG.allow_host_shell:
-        allow_host_terminal = True
-    response_dict = {}
-    response_dict[api_constants.MGMT_WEBAPP.HOST_TERMINAL_ALLOWED_PROPERTY] = allow_host_terminal
-    response = jsonify(response_dict)
-    return response, constants.HTTPS.OK_STATUS_CODE
